::: ropt.results
    options:
        members: False

::: ropt.results.Results
    options:
        heading_level: 3

::: ropt.results.ResultField
    options:
        heading_level: 3

::: ropt.results.FunctionResults
    options:
        heading_level: 3

::: ropt.results.FunctionEvaluations
    options:
        heading_level: 3
        members: False

::: ropt.results.Realizations
    options:
        heading_level: 3
        members: False

::: ropt.results.Functions
    options:
        heading_level: 3
        members: False

::: ropt.results.GradientResults
    options:
        heading_level: 3

::: ropt.results.GradientEvaluations
    options:
        heading_level: 3
        members: False

::: ropt.results.Gradients
    options:
        heading_level: 3
        members: False
